==> cgmail_0.6.orig.tar.gz: cgmail-0.6/cGmail/lib/common.py <==
# -*- coding: utf-8 -*-
#
#    Copyright (C) 2007 Marco Ferragina <marco.ferragina@gmail.com>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

import os
import gettext

import __builtin__
__builtin__._ = gettext.gettext

PROGRAM_NAME = "cGmail"
VERSION = "0.6"

AUTHORS = u"""Marco Ferragina <marco.ferragina@gmail.com>
Francesco Marella <francesco.marella@gmail.com>
""".splitlines()

COPYRIGHT = u"""Copyright (c) 2007,2008 Marco Ferragina
Copyright (c) 2009 Francesco Marella"""

LICENSE = _("""
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
""")

TRANSLATORS = _("translator-credits")

==> cgmail_0.6.1.orig.tar.gz: cgmail-0.6.1/cGmail/lib/common.py <==
# -*- coding: utf-8 -*-
#
#    Copyright (C) 2007 Marco Ferragina <marco.ferragina@gmail.com>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

import os
import gettext

import __builtin__
__builtin__._ = gettext.gettext

PROGRAM_NAME = "cGmail"
VERSION = "0.6.1"

AUTHORS = u"""Marco Ferragina <marco.ferragina@gmail.com>
Francesco Marella <francesco.marella@gmail.com>
Patrick Ulbrich <zulu99@gmx.net>

Jonathan Cristoforetti (patch, bugs, etc)
Andrea Veri <andrea.veri89@gmail.com> (Debian, Ubuntu)
""".splitlines()

COPYRIGHT = u"""Copyright (c) 2007,2008 Marco Ferragina
Copyright (c) 2009 cGmail Core Team"""

LICENSE = _("""
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
""")

TRANSLATORS = _("translator-credits")

BUGS_TRACKER = u"https://bugs.launchpad.net/cgmail/+filebug"

TRANSLATE_APP = u"https://translations.launchpad.net/cgmail"

ONLINE_SUPPORT = u"https://answers.launchpad.net/cgmail/+addquestion"
